==> amf-webapi_2.12-4.1.0-3-sources.jar: amf/client/model/domain/MqttServerBinding.scala <==
package amf.client.model.domain

import amf.client.convert.WebApiClientConverters._
import amf.client.model.{BoolField, StrField, IntField}

import scala.scalajs.js.annotation.{JSExportTopLevel, JSExportAll}
import amf.plugins.domain.webapi.models.bindings.mqtt.{
  MqttServerBinding => InternalMqttServerBinding,
  MqttServerLastWill => InternalMqttServerLastWill
}

@JSExportAll
case class MqttServerBinding(override private[amf] val _internal: InternalMqttServerBinding)
    extends ServerBinding
    with BindingVersion {
  @JSExportTopLevel("model.domain.MqttServerBinding")
  def this() = this(InternalMqttServerBinding())
  override protected def bindingVersion: StrField = _internal.bindingVersion
  override def withBindingVersion(bindingVersion: String): this.type = {
    _internal.withBindingVersion(bindingVersion)
    this
  }

  def clientId: StrField           = _internal.clientId
  def cleanSession: BoolField      = _internal.cleanSession
  def lastWill: MqttServerLastWill = _internal.lastWill
  def keepAlive: IntField          = _internal.keepAlive

  def withClientId(clientId: String): this.type = {
    _internal.withClientId(clientId)
    this
  }
  def withCleanSession(cleanSession: Boolean): this.type = {
    _internal.withCleanSession(cleanSession)
    this
  }
  def withLastWill(lastWill: MqttServerLastWill): this.type = {
    _internal.withLastWill(lastWill)
    this
  }
  def withKeepAlive(keepAlive: Int): this.type = {
    _internal.withKeepAlive(keepAlive)
    this
  }

  override def linkCopy(): MqttServerBinding = _internal.linkCopy()
}

@JSExportAll
case class MqttServerLastWill(override private[amf] val _internal: InternalMqttServerLastWill) extends DomainElement {
  @JSExportTopLevel("model.domain.MqttServerLastWill")
  def this() = this(InternalMqttServerLastWill())

  def topic: StrField   = _internal.topic
  def qos: IntField     = _internal.qos
  def retain: BoolField = _internal.retain

  def withTopic(topic: String): this.type = {
    _internal.withTopic(topic)
    this
  }
  def withQos(qos: Int): this.type = {
    _internal.withQos(qos)
    this
  }
  def withRetain(retain: Boolean): this.type = {
    _internal.withRetain(retain)
    this
  }
}

==> amf-webapi_2.12-4.7.8-4-sources.jar: amf/client/model/domain/MqttServerBinding.scala <==
package amf.client.model.domain

import amf.client.convert.WebApiClientConverters._
import amf.client.model.{BoolField, StrField, IntField}

import scala.scalajs.js.annotation.{JSExportTopLevel, JSExportAll}
import amf.plugins.domain.webapi.models.bindings.mqtt.{
  MqttServerBinding => InternalMqttServerBinding,
  MqttServerLastWill => InternalMqttServerLastWill
}

@JSExportAll
case class MqttServerBinding(override private[amf] val _internal: InternalMqttServerBinding)
    extends ServerBinding
    with BindingVersion {
  @JSExportTopLevel("model.domain.MqttServerBinding")
  def this() = this(InternalMqttServerBinding())
  override protected def bindingVersion: StrField = _internal.bindingVersion
  override def withBindingVersion(bindingVersion: String): this.type = {
    _internal.withBindingVersion(bindingVersion)
    this
  }

  def clientId: StrField           = _internal.clientId
  def cleanSession: BoolField      = _internal.cleanSession
  def lastWill: MqttServerLastWill = _internal.lastWill
  def keepAlive: IntField          = _internal.keepAlive

  def withClientId(clientId: String): this.type = {
    _internal.withClientId(clientId)
    this
  }
  def withCleanSession(cleanSession: Boolean): this.type = {
    _internal.withCleanSession(cleanSession)
    this
  }
  def withLastWill(lastWill: MqttServerLastWill): this.type = {
    _internal.withLastWill(lastWill)
    this
  }
  def withKeepAlive(keepAlive: Int): this.type = {
    _internal.withKeepAlive(keepAlive)
    this
  }

  override def linkCopy(): MqttServerBinding = _internal.linkCopy()
}

@JSExportAll
case class MqttServerLastWill(override private[amf] val _internal: InternalMqttServerLastWill) extends DomainElement {
  @JSExportTopLevel("model.domain.MqttServerLastWill")
  def this() = this(InternalMqttServerLastWill())

  def topic: StrField   = _internal.topic
  def qos: IntField     = _internal.qos
  def retain: BoolField = _internal.retain
  def message: StrField = _internal.message

  def withTopic(topic: String): this.type = {
    _internal.withTopic(topic)
    this
  }
  def withQos(qos: Int): this.type = {
    _internal.withQos(qos)
    this
  }
  def withRetain(retain: Boolean): this.type = {
    _internal.withRetain(retain)
    this
  }
  def withMessage(message: String): this.type = {
    _internal.withMessage(message)
    this
  }
}
